==> oci-java-sdk-shaded-full-3.40.0-sources.jar: com/oracle/bmc/core/model/InstanceSourceViaImageDetails.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.core.model;

/**
 * <br>
 * Note: Objects should always be created or deserialized using the {@link Builder}. This model
 * distinguishes fields that are {@code null} because they are unset from fields that are explicitly
 * set to {@code null}. This is done in the setter methods of the {@link Builder}, which maintain a
 * set of all explicitly set fields called {@link Builder#__explicitlySet__}. The {@link
 * #hashCode()} and {@link #equals(Object)} methods are implemented to take the explicitly set
 * fields into account. The constructor, on the other hand, does not take the explicitly set fields
 * into account (since the constructor cannot distinguish explicit {@code null} from unset {@code
 * null}).
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20160918")
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(
        builder = InstanceSourceViaImageDetails.Builder.class)
@com.fasterxml.jackson.annotation.JsonTypeInfo(
        use = com.fasterxml.jackson.annotation.JsonTypeInfo.Id.NAME,
        include = com.fasterxml.jackson.annotation.JsonTypeInfo.As.PROPERTY,
        property = "sourceType")
@com.fasterxml.jackson.annotation.JsonFilter(
        com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel.EXPLICITLY_SET_FILTER_NAME)
public final class InstanceSourceViaImageDetails extends InstanceSourceDetails {
    @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(withPrefix = "")
    public static class Builder {
        /**
         * The size of the boot volume in GBs. Minimum value is 50 GB and maximum value is 32,768 GB
         * (32 TB).
         */
        @com.fasterxml.jackson.annotation.JsonProperty("bootVolumeSizeInGBs")
        private Long bootVolumeSizeInGBs;

        /**
         * The size of the boot volume in GBs. Minimum value is 50 GB and maximum value is 32,768 GB
         * (32 TB).
         *
         * @param bootVolumeSizeInGBs the value to set
         * @return this builder
         */
        public Builder bootVolumeSizeInGBs(Long bootVolumeSizeInGBs) {
            this.bootVolumeSizeInGBs = bootVolumeSizeInGBs;
            this.__explicitlySet__.add("bootVolumeSizeInGBs");
            return this;
        }
        /** The OCID of the image used to boot the instance. */
        @com.fasterxml.jackson.annotation.JsonProperty("imageId")
        private String imageId;

        /**
         * The OCID of the image used to boot the instance.
         *
         * @param imageId the value to set
         * @return this builder
         */
        public Builder imageId(String imageId) {
            this.imageId = imageId;
            this.__explicitlySet__.add("imageId");
            return this;
        }
        /**
         * The OCID of the Vault service key to assign as the master encryption key for the boot
         * volume.
         */
        @com.fasterxml.jackson.annotation.JsonProperty("kmsKeyId")
        private String kmsKeyId;

        /**
         * The OCID of the Vault service key to assign as the master encryption key for the boot
         * volume.
         *
         * @param kmsKeyId the value to set
         * @return this builder
         */
        public Builder kmsKeyId(String kmsKeyId) {
            this.kmsKeyId = kmsKeyId;
            this.__explicitlySet__.add("kmsKeyId");
            return this;
        }
        /**
         * The number of volume performance units (VPUs) that will be applied to this volume per GB,
         * representing the Block Volume service's elastic performance options. See [Block Volume
         * Performance
         * Levels](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumeperformance.htm#perf_levels)
         * for more information.
         *
         * <p>Allowed values:
         *
         * <p>{@code 10}: Represents Balanced option.
         *
         * <p>{@code 20}: Represents Higher Performance option.
         *
         * <p>{@code 30}-{@code 120}: Represents the Ultra High Performance option.
         *
         * <p>For volumes with the auto-tuned performance feature enabled, this is set to the
         * default (minimum) VPUs/GB.
         */
        @com.fasterxml.jackson.annotation.JsonProperty("bootVolumeVpusPerGB")
        private Long bootVolumeVpusPerGB;

        /**
         * The number of volume performance units (VPUs) that will be applied to this volume per GB,
         * representing the Block Volume service's elastic performance options. See [Block Volume
         * Performance
         * Levels](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumeperformance.htm#perf_levels)
         * for more information.
         *
         * <p>Allowed values:
         *
         * <p>{@code 10}: Represents Balanced option.
         *
         * <p>{@code 20}: Represents Higher Performance option.
         *
         * <p>{@code 30}-{@code 120}: Represents the Ultra High Performance option.
         *
         * <p>For volumes with the auto-tuned performance feature enabled, this is set to the
         * default (minimum) VPUs/GB.
         *
         * @param bootVolumeVpusPerGB the value to set
         * @return this builder
         */
        public Builder bootVolumeVpusPerGB(Long bootVolumeVpusPerGB) {
            this.bootVolumeVpusPerGB = bootVolumeVpusPerGB;
            this.__explicitlySet__.add("bootVolumeVpusPerGB");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonProperty("instanceSourceImageFilterDetails")
        private InstanceSourceImageFilterDetails instanceSourceImageFilterDetails;

        public Builder instanceSourceImageFilterDetails(
                InstanceSourceImageFilterDetails instanceSourceImageFilterDetails) {
            this.instanceSourceImageFilterDetails = instanceSourceImageFilterDetails;
            this.__explicitlySet__.add("instanceSourceImageFilterDetails");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        private final java.util.Set<String> __explicitlySet__ = new java.util.HashSet<String>();

        public InstanceSourceViaImageDetails build() {
            InstanceSourceViaImageDetails model =
                    new InstanceSourceViaImageDetails(
                            this.bootVolumeSizeInGBs,
                            this.imageId,
                            this.kmsKeyId,
                            this.bootVolumeVpusPerGB,
                            this.instanceSourceImageFilterDetails);
            for (String explicitlySetProperty : this.__explicitlySet__) {
                model.markPropertyAsExplicitlySet(explicitlySetProperty);
            }
            return model;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        public Builder copy(InstanceSourceViaImageDetails model) {
            if (model.wasPropertyExplicitlySet("bootVolumeSizeInGBs")) {
                this.bootVolumeSizeInGBs(model.getBootVolumeSizeInGBs());
            }
            if (model.wasPropertyExplicitlySet("imageId")) {
                this.imageId(model.getImageId());
            }
            if (model.wasPropertyExplicitlySet("kmsKeyId")) {
                this.kmsKeyId(model.getKmsKeyId());
            }
            if (model.wasPropertyExplicitlySet("bootVolumeVpusPerGB")) {
                this.bootVolumeVpusPerGB(model.getBootVolumeVpusPerGB());
            }
            if (model.wasPropertyExplicitlySet("instanceSourceImageFilterDetails")) {
                this.instanceSourceImageFilterDetails(model.getInstanceSourceImageFilterDetails());
            }
            return this;
        }
    }

    /** Create a new builder. */
    public static Builder builder() {
        return new Builder();
    }

    public Builder toBuilder() {
        return new Builder().copy(this);
    }

    @Deprecated
    public InstanceSourceViaImageDetails(
            Long bootVolumeSizeInGBs,
            String imageId,
            String kmsKeyId,
            Long bootVolumeVpusPerGB,
            InstanceSourceImageFilterDetails instanceSourceImageFilterDetails) {
        super();
        this.bootVolumeSizeInGBs = bootVolumeSizeInGBs;
        this.imageId = imageId;
        this.kmsKeyId = kmsKeyId;
        this.bootVolumeVpusPerGB = bootVolumeVpusPerGB;
        this.instanceSourceImageFilterDetails = instanceSourceImageFilterDetails;
    }

    /**
     * The size of the boot volume in GBs. Minimum value is 50 GB and maximum value is 32,768 GB (32
     * TB).
     */
    @com.fasterxml.jackson.annotation.JsonProperty("bootVolumeSizeInGBs")
    private final Long bootVolumeSizeInGBs;

    /**
     * The size of the boot volume in GBs. Minimum value is 50 GB and maximum value is 32,768 GB (32
     * TB).
     *
     * @return the value
     */
    public Long getBootVolumeSizeInGBs() {
        return bootVolumeSizeInGBs;
    }

    /** The OCID of the image used to boot the instance. */
    @com.fasterxml.jackson.annotation.JsonProperty("imageId")
    private final String imageId;

    /**
     * The OCID of the image used to boot the instance.
     *
     * @return the value
     */
    public String getImageId() {
        return imageId;
    }

    /**
     * The OCID of the Vault service key to assign as the master encryption key for the boot volume.
     */
    @com.fasterxml.jackson.annotation.JsonProperty("kmsKeyId")
    private final String kmsKeyId;

    /**
     * The OCID of the Vault service key to assign as the master encryption key for the boot volume.
     *
     * @return the value
     */
    public String getKmsKeyId() {
        return kmsKeyId;
    }

    /**
     * The number of volume performance units (VPUs) that will be applied to this volume per GB,
     * representing the Block Volume service's elastic performance options. See [Block Volume
     * Performance
     * Levels](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumeperformance.htm#perf_levels)
     * for more information.
     *
     * <p>Allowed values:
     *
     * <p>{@code 10}: Represents Balanced option.
     *
     * <p>{@code 20}: Represents Higher Performance option.
     *
     * <p>{@code 30}-{@code 120}: Represents the Ultra High Performance option.
     *
     * <p>For volumes with the auto-tuned performance feature enabled, this is set to the default
     * (minimum) VPUs/GB.
     */
    @com.fasterxml.jackson.annotation.JsonProperty("bootVolumeVpusPerGB")
    private final Long bootVolumeVpusPerGB;

    /**
     * The number of volume performance units (VPUs) that will be applied to this volume per GB,
     * representing the Block Volume service's elastic performance options. See [Block Volume
     * Performance
     * Levels](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumeperformance.htm#perf_levels)
     * for more information.
     *
     * <p>Allowed values:
     *
     * <p>{@code 10}: Represents Balanced option.
     *
     * <p>{@code 20}: Represents Higher Performance option.
     *
     * <p>{@code 30}-{@code 120}: Represents the Ultra High Performance option.
     *
     * <p>For volumes with the auto-tuned performance feature enabled, this is set to the default
     * (minimum) VPUs/GB.
     *
     * @return the value
     */
    public Long getBootVolumeVpusPerGB() {
        return bootVolumeVpusPerGB;
    }

    @com.fasterxml.jackson.annotation.JsonProperty("instanceSourceImageFilterDetails")
    private final InstanceSourceImageFilterDetails instanceSourceImageFilterDetails;

    public InstanceSourceImageFilterDetails getInstanceSourceImageFilterDetails() {
        return instanceSourceImageFilterDetails;
    }

    @Override
    public String toString() {
        return this.toString(true);
    }

    /**
     * Return a string representation of the object.
     *
     * @param includeByteArrayContents true to include the full contents of byte arrays
     * @return string representation
     */
    public String toString(boolean includeByteArrayContents) {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("InstanceSourceViaImageDetails(");
        sb.append("super=").append(super.toString(includeByteArrayContents));
        sb.append(", bootVolumeSizeInGBs=").append(String.valueOf(this.bootVolumeSizeInGBs));
        sb.append(", imageId=").append(String.valueOf(this.imageId));
        sb.append(", kmsKeyId=").append(String.valueOf(this.kmsKeyId));
        sb.append(", bootVolumeVpusPerGB=").append(String.valueOf(this.bootVolumeVpusPerGB));
        sb.append(", instanceSourceImageFilterDetails=")
                .append(String.valueOf(this.instanceSourceImageFilterDetails));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof InstanceSourceViaImageDetails)) {
            return false;
        }

        InstanceSourceViaImageDetails other = (InstanceSourceViaImageDetails) o;
        return java.util.Objects.equals(this.bootVolumeSizeInGBs, other.bootVolumeSizeInGBs)
                && java.util.Objects.equals(this.imageId, other.imageId)
                && java.util.Objects.equals(this.kmsKeyId, other.kmsKeyId)
                && java.util.Objects.equals(this.bootVolumeVpusPerGB, other.bootVolumeVpusPerGB)
                && java.util.Objects.equals(
                        this.instanceSourceImageFilterDetails,
                        other.instanceSourceImageFilterDetails)
                && super.equals(other);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.bootVolumeSizeInGBs == null
                                ? 43
                                : this.bootVolumeSizeInGBs.hashCode());
        result = (result * PRIME) + (this.imageId == null ? 43 : this.imageId.hashCode());
        result = (result * PRIME) + (this.kmsKeyId == null ? 43 : this.kmsKeyId.hashCode());
        result =
                (result * PRIME)
                        + (this.bootVolumeVpusPerGB == null
                                ? 43
                                : this.bootVolumeVpusPerGB.hashCode());
        result =
                (result * PRIME)
                        + (this.instanceSourceImageFilterDetails == null
                                ? 43
                                : this.instanceSourceImageFilterDetails.hashCode());
        return result;
    }
}

==> oci-java-sdk-shaded-full-3.63.1-sources.jar: com/oracle/bmc/core/model/InstanceSourceViaImageDetails.java <==
/**
 * Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.core.model;

/**
 * <br>
 * Note: Objects should always be created or deserialized using the {@link Builder}. This model
 * distinguishes fields that are {@code null} because they are unset from fields that are explicitly
 * set to {@code null}. This is done in the setter methods of the {@link Builder}, which maintain a
 * set of all explicitly set fields called {@link Builder#__explicitlySet__}. The {@link
 * #hashCode()} and {@link #equals(Object)} methods are implemented to take the explicitly set
 * fields into account. The constructor, on the other hand, does not take the explicitly set fields
 * into account (since the constructor cannot distinguish explicit {@code null} from unset {@code
 * null}).
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20160918")
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(
        builder = InstanceSourceViaImageDetails.Builder.class)
@com.fasterxml.jackson.annotation.JsonTypeInfo(
        use = com.fasterxml.jackson.annotation.JsonTypeInfo.Id.NAME,
        include = com.fasterxml.jackson.annotation.JsonTypeInfo.As.PROPERTY,
        property = "sourceType")
@com.fasterxml.jackson.annotation.JsonFilter(
        com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel.EXPLICITLY_SET_FILTER_NAME)
public final class InstanceSourceViaImageDetails extends InstanceSourceDetails {
    @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(withPrefix = "")
    public static class Builder {
        /**
         * The size of the boot volume in GBs. Minimum value is 50 GB and maximum value is 32,768 GB
         * (32 TB).
         */
        @com.fasterxml.jackson.annotation.JsonProperty("bootVolumeSizeInGBs")
        private Long bootVolumeSizeInGBs;

        /**
         * The size of the boot volume in GBs. Minimum value is 50 GB and maximum value is 32,768 GB
         * (32 TB).
         *
         * @param bootVolumeSizeInGBs the value to set
         * @return this builder
         */
        public Builder bootVolumeSizeInGBs(Long bootVolumeSizeInGBs) {
            this.bootVolumeSizeInGBs = bootVolumeSizeInGBs;
            this.__explicitlySet__.add("bootVolumeSizeInGBs");
            return this;
        }
        /** The OCID of the image used to boot the instance. */
        @com.fasterxml.jackson.annotation.JsonProperty("imageId")
        private String imageId;

        /**
         * The OCID of the image used to boot the instance.
         *
         * @param imageId the value to set
         * @return this builder
         */
        public Builder imageId(String imageId) {
            this.imageId = imageId;
            this.__explicitlySet__.add("imageId");
            return this;
        }
        /**
         * The OCID of the Vault service key to assign as the master encryption key for the boot
         * volume.
         */
        @com.fasterxml.jackson.annotation.JsonProperty("kmsKeyId")
        private String kmsKeyId;

        /**
         * The OCID of the Vault service key to assign as the master encryption key for the boot
         * volume.
         *
         * @param kmsKeyId the value to set
         * @return this builder
         */
        public Builder kmsKeyId(String kmsKeyId) {
            this.kmsKeyId = kmsKeyId;
            this.__explicitlySet__.add("kmsKeyId");
            return this;
        }
        /**
         * The number of volume performance units (VPUs) that will be applied to this volume per GB,
         * representing the Block Volume service's elastic performance options. See [Block Volume
         * Performance
         * Levels](https://docs.oracle.com/iaas/Content/Block/Concepts/blockvolumeperformance.htm#perf_levels)
         * for more information.
         *
         * <p>Allowed values:
         *
         * <p>{@code 10}: Represents Balanced option.
         *
         * <p>{@code 20}: Represents Higher Performance option.
         *
         * <p>{@code 30}-{@code 120}: Represents the Ultra High Performance option.
         *
         * <p>For volumes with the auto-tuned performance feature enabled, this is set to the
         * default (minimum) VPUs/GB.
         */
        @com.fasterxml.jackson.annotation.JsonProperty("bootVolumeVpusPerGB")
        private Long bootVolumeVpusPerGB;

        /**
         * The number of volume performance units (VPUs) that will be applied to this volume per GB,
         * representing the Block Volume service's elastic performance options. See [Block Volume
         * Performance
         * Levels](https://docs.oracle.com/iaas/Content/Block/Concepts/blockvolumeperformance.htm#perf_levels)
         * for more information.
         *
         * <p>Allowed values:
         *
         * <p>{@code 10}: Represents Balanced option.
         *
         * <p>{@code 20}: Represents Higher Performance option.
         *
         * <p>{@code 30}-{@code 120}: Represents the Ultra High Performance option.
         *
         * <p>For volumes with the auto-tuned performance feature enabled, this is set to the
         * default (minimum) VPUs/GB.
         *
         * @param bootVolumeVpusPerGB the value to set
         * @return this builder
         */
        public Builder bootVolumeVpusPerGB(Long bootVolumeVpusPerGB) {
            this.bootVolumeVpusPerGB = bootVolumeVpusPerGB;
            this.__explicitlySet__.add("bootVolumeVpusPerGB");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonProperty("instanceSourceImageFilterDetails")
        private InstanceSourceImageFilterDetails instanceSourceImageFilterDetails;

        public Builder instanceSourceImageFilterDetails(
                InstanceSourceImageFilterDetails instanceSourceImageFilterDetails) {
            this.instanceSourceImageFilterDetails = instanceSourceImageFilterDetails;
            this.__explicitlySet__.add("instanceSourceImageFilterDetails");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        private final java.util.Set<String> __explicitlySet__ = new java.util.HashSet<String>();

        public InstanceSourceViaImageDetails build() {
            InstanceSourceViaImageDetails model =
                    new InstanceSourceViaImageDetails(
                            this.bootVolumeSizeInGBs,
                            this.imageId,
                            this.kmsKeyId,
                            this.bootVolumeVpusPerGB,
                            this.instanceSourceImageFilterDetails);
            for (String explicitlySetProperty : this.__explicitlySet__) {
                model.markPropertyAsExplicitlySet(explicitlySetProperty);
            }
            return model;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        public Builder copy(InstanceSourceViaImageDetails model) {
            if (model.wasPropertyExplicitlySet("bootVolumeSizeInGBs")) {
                this.bootVolumeSizeInGBs(model.getBootVolumeSizeInGBs());
            }
            if (model.wasPropertyExplicitlySet("imageId")) {
                this.imageId(model.getImageId());
            }
            if (model.wasPropertyExplicitlySet("kmsKeyId")) {
                this.kmsKeyId(model.getKmsKeyId());
            }
            if (model.wasPropertyExplicitlySet("bootVolumeVpusPerGB")) {
                this.bootVolumeVpusPerGB(model.getBootVolumeVpusPerGB());
            }
            if (model.wasPropertyExplicitlySet("instanceSourceImageFilterDetails")) {
                this.instanceSourceImageFilterDetails(model.getInstanceSourceImageFilterDetails());
            }
            return this;
        }
    }

    /** Create a new builder. */
    public static Builder builder() {
        return new Builder();
    }

    public Builder toBuilder() {
        return new Builder().copy(this);
    }

    @Deprecated
    public InstanceSourceViaImageDetails(
            Long bootVolumeSizeInGBs,
            String imageId,
            String kmsKeyId,
            Long bootVolumeVpusPerGB,
            InstanceSourceImageFilterDetails instanceSourceImageFilterDetails) {
        super();
        this.bootVolumeSizeInGBs = bootVolumeSizeInGBs;
        this.imageId = imageId;
        this.kmsKeyId = kmsKeyId;
        this.bootVolumeVpusPerGB = bootVolumeVpusPerGB;
        this.instanceSourceImageFilterDetails = instanceSourceImageFilterDetails;
    }

    /**
     * The size of the boot volume in GBs. Minimum value is 50 GB and maximum value is 32,768 GB (32
     * TB).
     */
    @com.fasterxml.jackson.annotation.JsonProperty("bootVolumeSizeInGBs")
    private final Long bootVolumeSizeInGBs;

    /**
     * The size of the boot volume in GBs. Minimum value is 50 GB and maximum value is 32,768 GB (32
     * TB).
     *
     * @return the value
     */
    public Long getBootVolumeSizeInGBs() {
        return bootVolumeSizeInGBs;
    }

    /** The OCID of the image used to boot the instance. */
    @com.fasterxml.jackson.annotation.JsonProperty("imageId")
    private final String imageId;

    /**
     * The OCID of the image used to boot the instance.
     *
     * @return the value
     */
    public String getImageId() {
        return imageId;
    }

    /**
     * The OCID of the Vault service key to assign as the master encryption key for the boot volume.
     */
    @com.fasterxml.jackson.annotation.JsonProperty("kmsKeyId")
    private final String kmsKeyId;

    /**
     * The OCID of the Vault service key to assign as the master encryption key for the boot volume.
     *
     * @return the value
     */
    public String getKmsKeyId() {
        return kmsKeyId;
    }

    /**
     * The number of volume performance units (VPUs) that will be applied to this volume per GB,
     * representing the Block Volume service's elastic performance options. See [Block Volume
     * Performance
     * Levels](https://docs.oracle.com/iaas/Content/Block/Concepts/blockvolumeperformance.htm#perf_levels)
     * for more information.
     *
     * <p>Allowed values:
     *
     * <p>{@code 10}: Represents Balanced option.
     *
     * <p>{@code 20}: Represents Higher Performance option.
     *
     * <p>{@code 30}-{@code 120}: Represents the Ultra High Performance option.
     *
     * <p>For volumes with the auto-tuned performance feature enabled, this is set to the default
     * (minimum) VPUs/GB.
     */
    @com.fasterxml.jackson.annotation.JsonProperty("bootVolumeVpusPerGB")
    private final Long bootVolumeVpusPerGB;

    /**
     * The number of volume performance units (VPUs) that will be applied to this volume per GB,
     * representing the Block Volume service's elastic performance options. See [Block Volume
     * Performance
     * Levels](https://docs.oracle.com/iaas/Content/Block/Concepts/blockvolumeperformance.htm#perf_levels)
     * for more information.
     *
     * <p>Allowed values:
     *
     * <p>{@code 10}: Represents Balanced option.
     *
     * <p>{@code 20}: Represents Higher Performance option.
     *
     * <p>{@code 30}-{@code 120}: Represents the Ultra High Performance option.
     *
     * <p>For volumes with the auto-tuned performance feature enabled, this is set to the default
     * (minimum) VPUs/GB.
     *
     * @return the value
     */
    public Long getBootVolumeVpusPerGB() {
        return bootVolumeVpusPerGB;
    }

    @com.fasterxml.jackson.annotation.JsonProperty("instanceSourceImageFilterDetails")
    private final InstanceSourceImageFilterDetails instanceSourceImageFilterDetails;

    public InstanceSourceImageFilterDetails getInstanceSourceImageFilterDetails() {
        return instanceSourceImageFilterDetails;
    }

    @Override
    public String toString() {
        return this.toString(true);
    }

    /**
     * Return a string representation of the object.
     *
     * @param includeByteArrayContents true to include the full contents of byte arrays
     * @return string representation
     */
    public String toString(boolean includeByteArrayContents) {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("InstanceSourceViaImageDetails(");
        sb.append("super=").append(super.toString(includeByteArrayContents));
        sb.append(", bootVolumeSizeInGBs=").append(String.valueOf(this.bootVolumeSizeInGBs));
        sb.append(", imageId=").append(String.valueOf(this.imageId));
        sb.append(", kmsKeyId=").append(String.valueOf(this.kmsKeyId));
        sb.append(", bootVolumeVpusPerGB=").append(String.valueOf(this.bootVolumeVpusPerGB));
        sb.append(", instanceSourceImageFilterDetails=")
                .append(String.valueOf(this.instanceSourceImageFilterDetails));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof InstanceSourceViaImageDetails)) {
            return false;
        }

        InstanceSourceViaImageDetails other = (InstanceSourceViaImageDetails) o;
        return java.util.Objects.equals(this.bootVolumeSizeInGBs, other.bootVolumeSizeInGBs)
                && java.util.Objects.equals(this.imageId, other.imageId)
                && java.util.Objects.equals(this.kmsKeyId, other.kmsKeyId)
                && java.util.Objects.equals(this.bootVolumeVpusPerGB, other.bootVolumeVpusPerGB)
                && java.util.Objects.equals(
                        this.instanceSourceImageFilterDetails,
                        other.instanceSourceImageFilterDetails)
                && super.equals(other);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.bootVolumeSizeInGBs == null
                                ? 43
                                : this.bootVolumeSizeInGBs.hashCode());
        result = (result * PRIME) + (this.imageId == null ? 43 : this.imageId.hashCode());
        result = (result * PRIME) + (this.kmsKeyId == null ? 43 : this.kmsKeyId.hashCode());
        result =
                (result * PRIME)
                        + (this.bootVolumeVpusPerGB == null
                                ? 43
                                : this.bootVolumeVpusPerGB.hashCode());
        result =
                (result * PRIME)
                        + (this.instanceSourceImageFilterDetails == null
                                ? 43
                                : this.instanceSourceImageFilterDetails.hashCode());
        return result;
    }
}
